#!/usr/bin/env perl

# Copyright INRA/CNRS

# Sebastien.Carrere@toulouse.inra.fr
# Jerome.Gouzy@toulouse.inra.fr

# This software is a computer program whose purpose is to provide a
# web-based interface for analyzing the different levels of genome
# conservations.

# This software is governed by the CeCILL license under French law and
# abiding by the rules of distribution of free software.  You can  use,
# modify and/ or redistribute the software under the terms of the CeCILL
# license as circulated by CEA, CNRS and INRIA at the following URL
# "http://www.cecill.info".

# As a counterpart to the access to the source code and  rights to copy,
# modify and redistribute granted by the license, users are provided only
# with a limited warranty  and the software's author,  the holder of the
# economic rights,  and the successive licensors  have only  limited
# liability.

# In this respect, the user's attention is drawn to the risks associated
# with loading,  using,  modifying and/or developing or reproducing the
# software by the user in light of its specific status of free software,
# that may mean  that it is complicated to manipulate,  and  that  also
# therefore means  that it is reserved for developers  and  experienced
# professionals having in-depth computer knowledge. Users are therefore
# encouraged to load and test the software's suitability as regards their
# requirements in conditions enabling the security of their systems and/or
# data to be ensured and,  more generally, to use and operate it in the
# same conditions as regards security.

# The fact that you are presently reading this means that you have had
# knowledge of the CeCILL license and that you accept its terms.

package iANT::Cfg;

use strict;
use warnings;
use Carp;
require 'UNIVERSAL.pl';

=head1 NAME

iANT::Cfg - Object to deal with cfg files


=head1 SYNOPSIS

    use iANT;


=head1 DESCRIPTION

    iANT package contains a set of methods (Get, Set, Dump)used by the following modules:
    

=cut

=pod

=head3 procedure Load

 Title        : Load
 Usage        : 
 Prerequisite : 
 Function     : 
 Returns      : 
 Args         : 
 Globals      : 

=cut

sub Load
{
    my $o_param = shift();
   
   my $verbose = 1;
   
    $verbose = 0 if ((defined $o_param) && (ref ($o_param) =~ /paramparser/i) && (! $o_param->IsDefined('verbose')));
    
    my $main_cfg;

    if (defined $ENV{'IANTCFG'})
    {
        $main_cfg = $ENV{'IANTCFG'};
    }
    else
    {
        #print STDERR "\n\nYou should define IANTCFG Environnement variable (/path/to/iANT.cfg) to avoid any problem...\n" if ($verbose);
        my ($call_dir) = ($0 =~ /(.+\/)\S+$/);
        if (-e $call_dir . '../cfg/iANT.cfg')
        {
            $main_cfg = $call_dir . '../cfg/iANT.cfg';
        }
        elsif  (-e $call_dir . '../../cfg/iANT.cfg')
        {
            $main_cfg = $call_dir . '../../cfg/iANT.cfg';
        }
        elsif  (-e $call_dir . '../../../cfg/iANT.cfg')
        {
            $main_cfg = $call_dir . '../../../cfg/iANT.cfg';
        }
        else
        {
            print STDERR "\n\n ERROR: Failed\n\niANT.cfg NOT Found from $call_dir...\n";
            exit;
        }
    }
    use Cwd 'abs_path';
    my $abs_path = abs_path($main_cfg);


    #print STDERR "iANT: Configuration file: IANTCFG=$abs_path\n" if ($verbose); 
    
    if ((! defined $o_param) || (ref ($o_param) !~ /paramparser/i))
    {
        $o_param = New ParamParser ('INIT');
	$o_param->UnsetBehaviour('assert_value_secure');
	$o_param->Update($main_cfg,'O');
	$o_param->SetBehaviour('use_substitution_table');
	
    }
    else
    { 
    $o_param->SetBehaviour('use_substitution_table');
    $o_param->UnsetBehaviour('assert_value_secure');
	$o_param->Update($main_cfg,'A');
    }
    
    my $install_dir = $o_param->Get('install_dir');
    ($install_dir) = ($abs_path =~ /(.+)\/.+\/.+\/.+/)  if (! $o_param->IsDefined('install_dir') || ! (-d $install_dir));
    #$o_param->Update($main_cfg,'A'); #on recupere la valeur de 'install_dir' pour faire les substitutions
    $o_param->SetSubstitution('%I',\$install_dir);
    $o_param->Update($main_cfg,'O'); #la les substitutions seront effectives !

    $o_param->SetSubstitution('%i',\$o_param->Get('internal_programs_dir'));
    $o_param->SetSubstitution('%e',\$o_param->Get('external_programs_dir'));
    $o_param->SetSubstitution('%g',\$o_param->Get('cgi_dir'));
        
    $o_param->Update($o_param->Get('cfg_dir') . '/iANT.programs.cfg', 'A');
    
    $o_param->SetSubstitution('%x',\$o_param->Get('xsl_dir'));
    $o_param->Update($o_param->Get('cfg_dir') . '/iANT.xsl.cfg', 'A');

    $o_param->SetSubstitution('%d',\$o_param->Get('db_dir'));
    $o_param->Update($o_param->Get('cfg_dir') . '/iANT.db.cfg', 'A');
    
    $o_param->SetSubstitution('%t',\$o_param->Get('tpl_dir'));
    $o_param->SetSubstitution('%w',\$o_param->Get('web_dir'));
    $o_param->Update($o_param->Get('cfg_dir') . '/iANT.tpl.cfg', 'A');
    
    $o_param->SetSubstitution('%c',\$o_param->Get('cfg_dir'));
    $o_param->Update($o_param->Get('cfg_dir') . '/iANT.prj.cfg', 'A');
    $o_param->UnsetBehaviour('assert_value_secure');
    return $o_param;
}


1;
